pub struct Ref<'a, T: 'a + ?Sized> { /* private fields */ }Expand description
A lightweight wrapper around a non-null pointer for a shared reference.
The wrappers are useful when you need a pointer instead of a reference while not degrading usage
and keeping its provenance. For instance, if you make the Ref from a mutable reference, the
fact the type is made from “mutable” won’t be lost, which is an information which some tools,
such as miri, used for finding pointer safety violations.
Implementations