Ref

Struct Ref 

pub struct Ref<'a, T: 'a + ?Sized> { /* private fields */ }
A lightweight wrapper around a non-null pointer for a shared reference.

The wrappers are useful when you need a pointer instead of a reference while not degrading usage and keeping its provenance. For instance, if you make the Ref from a mutable reference, the fact the type is made from “mutable” won’t be lost, which is an information which some tools, such as miri, used for finding pointer safety violations.

Implementations

Source

impl<'a, T: 'a + ?Sized> Ref<'a, T>

pub const fn from_ref(r: &'a T) -> Self

pub fn from_mut(r: &'a mut T) -> Self

pub fn as_ref(&self) -> &'a T

pub const fn as_nonnull(self) -> NonNull<T>

pub const fn as_ptr(self) -> *mut T